@@ -77,7 +77,7 @@ class Compiler(object):
         self.buf = [self.compile_top()]
         self.lastBufferedIdx = -1
         self.visit(self.node)
-        return ''.join(self.buf)
+        return unicode(u''.join(self.buf))
 
     def setDoctype(self,name):
         self.doctype = self.doctypes.get(name or 'default','<!DOCTYPE %s>'%name)
@@ -93,7 +93,7 @@ class Compiler(object):
             self.lastBuffered = str;
             self.lastBufferedIdx = len(self.buf)
 
-    def visit(self,node):
+    def visit(self,node,*args,**kwargs):
         # debug = self.debug
         # if debug:
         #     self.buf.append('__jade.unshift({ lineno: %d, filename: %s });' % (node.line,('"%s"'%node.filename) if node.filename else '__jade[0].filename'));
@@ -102,13 +102,13 @@ class Compiler(object):
         #     self.buf.pop()
         #     self.buf.pop()
 
-        self.visitNode(node)
+        self.visitNode(node,*args,**kwargs)
         # if debug: self.buf.append('__jade.shift();')
 
-    def visitNode (self,node):
+    def visitNode (self,node,*args,**kwargs):
         name = node.__class__.__name__
         # print name, node
-        return getattr(self,'visit%s'%name)(node)
+        return getattr(self,'visit%s'%name)(node,*args,**kwargs)
 
     def visitLiteral(self,node):
         self.buffer(node.str)
@@ -163,7 +163,9 @@ class Compiler(object):
             if self.pp and not name in self.inlineTags and not tag.textOnly:
                 self.buffer('\n')
 
-            self.buffer('%s</%s>'%(('  '*(self.indents-1) if not name in self.inlineTags else ''),name))
+            if self.pp and (not name in self.inlineTags):
+                self.buffer('  '*(self.indents-1))
+            self.buffer('</%s>'%name)
         self.indents -= 1
 
     def visitFilter(self,filter):
